"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _timm = require("timm");

var _storyboard = require("storyboard");

var _readSpecs = require("./utils/readSpecs");

var _constants = require("./utils/constants");

var _helpers = require("./utils/helpers");

var _writeSpecs = _interopRequireDefault(require("./utils/writeSpecs"));

var _shell = require("./utils/shell");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const run = async (deps, opts) => {
  const {
    src,
    ignoreSrc,
    link: linkPattern
  } = opts;
  const allSpecs = await (0, _readSpecs.readAllSpecs)(src, ignoreSrc);
  const pkgNames = Object.keys(allSpecs); // Determine correct version for each dep

  const versions = {};

  for (let i = 0; i < deps.length; i++) {
    const dep = deps[i];
    const {
      name,
      version
    } = (0, _helpers.parseDep)(dep);
    let finalVersion = version;

    if (!finalVersion) {
      if (pkgNames.indexOf(dep) >= 0) {
        finalVersion = `^${allSpecs[dep].specs.version}`;
      } else if (linkPattern && new RegExp(linkPattern).test(dep)) {
        finalVersion = '*';
      } else {
        const {
          stdout
        } = await (0, _shell.exec)(`npm info ${dep} version`, {
          logLevel: 'trace'
        });
        finalVersion = `^${stdout.trim()}`;
      }
    }

    versions[name] = finalVersion;
  }

  _storyboard.mainStory.info('New versions of these packages:', {
    attach: versions
  }); // Update all package.json files with this version


  pkgNames.forEach(pkgName => {
    const {
      specPath,
      specs: prevSpecs
    } = allSpecs[pkgName];
    let nextSpecs = prevSpecs;
    deps.forEach(dep => {
      const {
        name: depName
      } = (0, _helpers.parseDep)(dep);

      _constants.DEP_TYPES.forEach(type => {
        const depsOfType = nextSpecs[type] || {};

        if (depsOfType[depName] != null) {
          nextSpecs = (0, _timm.setIn)(nextSpecs, [type, depName], versions[depName]);
        }
      });
    });
    if (nextSpecs !== prevSpecs) (0, _writeSpecs.default)(specPath, nextSpecs);
  });
};

var _default = run;
exports.default = _default;