"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _storyboard = require("storyboard");

var _semver = _interopRequireDefault(require("semver"));

var _readSpecs = require("./utils/readSpecs");

var _removeInternalLinks = _interopRequireDefault(require("./utils/removeInternalLinks"));

var _writeSpecs = _interopRequireDefault(require("./utils/writeSpecs"));

var _shell = require("./utils/shell");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const run = async opts => {
  const {
    src,
    ignoreSrc,
    link: linkPattern
  } = opts;
  const allSpecs = await (0, _readSpecs.readAllSpecs)(src, ignoreSrc);
  const pkgNames = Object.keys(allSpecs);

  for (let i = 0; i < pkgNames.length; i++) {
    const pkgName = pkgNames[i];
    const {
      pkgPath,
      specPath,
      specs: prevSpecs
    } = allSpecs[pkgName];

    const story = _storyboard.mainStory.child({
      title: `Outdated dependencies in ${_storyboard.chalk.cyan.bold(pkgName)}`,
      level: 'info'
    }); // Rewrite package.json without own/linked packages, run `yarn outdated`, and revert changes


    let fModified = false;
    let allRemovedPackages;

    try {
      const tmp = (0, _removeInternalLinks.default)(prevSpecs, pkgNames, linkPattern);
      const {
        nextSpecs
      } = tmp;
      ({
        allRemovedPackages
      } = tmp);

      if (nextSpecs !== prevSpecs) {
        (0, _writeSpecs.default)(specPath, nextSpecs);
        fModified = true;
      }

      await (0, _shell.exec)('yarn outdated', {
        cwd: pkgPath,
        story,
        createChildStory: false,
        ignoreErrorCode: true,
        logLevel: 'trace'
      });
    } catch (err) {
      story.close();
      throw err;
    } finally {
      if (prevSpecs != null && fModified) (0, _writeSpecs.default)(specPath, prevSpecs);
    } // Log warnings when linked sub-packages do not match the specified range


    try {
      Object.keys(allRemovedPackages).forEach(depName => {
        const depVersionRange = allRemovedPackages[depName];
        const depSpecs = allSpecs[depName];
        if (!depSpecs) return; // might not exist, if it's a custom link

        const depActualVersion = depSpecs.specs.version;

        if (!_semver.default.satisfies(depActualVersion, depVersionRange)) {
          story.warn(`| - Warning: ${_storyboard.chalk.cyan.bold(`${depName}@${depActualVersion}`)} ` + `does not satisfy the specified range: ${_storyboard.chalk.cyan.bold(depVersionRange)}`);
        }
      });
    } finally {
      story.close();
    }
  }
};

var _default = run;
exports.default = _default;