"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _path = _interopRequireDefault(require("path"));

var _timm = require("timm");

var _semver = _interopRequireDefault(require("semver"));

var _storyboard = require("storyboard");

var _readSpecs = require("./utils/readSpecs");

var _writeSpecs = _interopRequireDefault(require("./utils/writeSpecs"));

var _shell = require("./utils/shell");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const run = async ({
  src,
  ignoreSrc,
  copyAttrs: copyAttrsStr
}) => {
  const allSpecs = await (0, _readSpecs.readAllSpecs)(src, ignoreSrc);
  const pkgNames = Object.keys(allSpecs);
  const rootSpecs = allSpecs[_readSpecs.ROOT_PACKAGE].specs; // Check version numbers!

  const masterVersion = rootSpecs.version;

  for (let i = 0; i < pkgNames.length; i++) {
    const pkgName = pkgNames[i];
    if (pkgName === _readSpecs.ROOT_PACKAGE) continue;
    const {
      specs
    } = allSpecs[pkgName];
    const {
      version
    } = specs;
    if (specs.private) continue;

    if (!_semver.default.valid(version)) {
      _storyboard.mainStory.error(`Invalid version for ${_storyboard.chalk.bold(pkgName)}: ${_storyboard.chalk.bold(version)}`);

      throw new Error('INVALID_VERSION');
    }

    if (_semver.default.gt(version, masterVersion)) {
      _storyboard.mainStory.error(`Version for ${pkgName} (${_storyboard.chalk.bold(version)}) > master version (${_storyboard.chalk.bold(masterVersion)})`);

      throw new Error('INVALID_VERSION');
    }
  } // Copy READMEs to all non-private packages


  for (let i = 0; i < pkgNames.length; i++) {
    const pkgName = pkgNames[i];
    if (pkgName === _readSpecs.ROOT_PACKAGE) continue;
    const {
      pkgPath,
      specs
    } = allSpecs[pkgName];
    if (specs.private) continue;
    const srcFile = pkgName === rootSpecs.name ? 'README.md' : 'README-LINK.md';

    const dstFile = _path.default.join(pkgPath, 'README.md');

    (0, _shell.cp)(srcFile, dstFile);
  } // Merge common attributes with submodules


  const commonSpecs = {};
  const copyAttrs = copyAttrsStr.split(/\s*,\s*/);
  copyAttrs.forEach(attr => {
    commonSpecs[attr] = rootSpecs[attr];
  });

  _storyboard.mainStory.info('Updating package attributes', {
    attach: commonSpecs
  });

  for (let i = 0; i < pkgNames.length; i++) {
    const pkgName = pkgNames[i];
    if (pkgName === _readSpecs.ROOT_PACKAGE) continue;
    const {
      specPath,
      specs: prevSpecs
    } = allSpecs[pkgName];
    if (prevSpecs.private) continue;
    const nextSpecs = (0, _timm.merge)(prevSpecs, commonSpecs);
    (0, _writeSpecs.default)(specPath, nextSpecs);
  }

  _storyboard.mainStory.warn('Please make sure you commit all changes before you attempt "oao publish"');
};

var _default = run;
exports.default = _default;