"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _timm = require("timm");

var _readSpecs = require("./utils/readSpecs");

var _constants = require("./utils/constants");

var _helpers = require("./utils/helpers");

var _writeSpecs = _interopRequireDefault(require("./utils/writeSpecs"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const run = async (deps, opts) => {
  const {
    src,
    ignoreSrc
  } = opts;
  const allSpecs = await (0, _readSpecs.readAllSpecs)(src, ignoreSrc);
  const pkgNames = Object.keys(allSpecs); // Update all package.json files with this version

  pkgNames.forEach(pkgName => {
    const {
      specPath,
      specs: prevSpecs
    } = allSpecs[pkgName];
    let nextSpecs = prevSpecs;
    deps.forEach(dep => {
      const {
        name: depName
      } = (0, _helpers.parseDep)(dep);

      _constants.DEP_TYPES.forEach(type => {
        const depsOfType = nextSpecs[type] || {};

        if (depsOfType[depName] != null) {
          const nextDeps = (0, _timm.omit)(depsOfType, [depName]);
          nextSpecs = (0, _timm.set)(nextSpecs, type, nextDeps);
        }
      });
    });
    if (nextSpecs !== prevSpecs) (0, _writeSpecs.default)(specPath, nextSpecs);
  });
};

var _default = run;
exports.default = _default;