"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _timm = require("timm");

var _storyboard = require("storyboard");

var _inquirer = _interopRequireDefault(require("inquirer"));

var _semver = _interopRequireDefault(require("semver"));

var _readSpecs = require("./utils/readSpecs");

var _writeSpecs = _interopRequireDefault(require("./utils/writeSpecs"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const run = async (version, {
  src,
  ignoreSrc,
  confirm = true
}) => {
  if (!_semver.default.valid(version)) {
    _storyboard.mainStory.error(`Version ${version} is not valid`);

    throw new Error('INVALID_VERSION');
  }

  const allSpecs = await (0, _readSpecs.readAllSpecs)(src, ignoreSrc);
  const pkgNames = Object.keys(allSpecs); // Ask for confirmation

  if (confirm) {
    const {
      goAhead
    } = await _inquirer.default.prompt([{
      name: 'goAhead',
      type: 'confirm',
      message: 'Are you sure you want to reset the version number of all packages, ' + `including the monorepo root, to ${_storyboard.chalk.cyan.yellow(version)} ` + `(${_storyboard.chalk.cyan.bold(pkgNames.length)} package/s, including monorepo)?`,
      default: false
    }]);
    if (!goAhead) process.exit(0);
  }

  for (let i = 0; i < pkgNames.length; i++) {
    const pkgName = pkgNames[i];
    const {
      specPath,
      specs: prevSpecs
    } = allSpecs[pkgName];
    const nextSpecs = (0, _timm.set)(prevSpecs, 'version', version);
    (0, _writeSpecs.default)(specPath, nextSpecs);
  }
};

var _default = run;
exports.default = _default;