"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.gitPushWithTags = exports.gitAddTag = exports.gitCommitChanges = exports.gitDiffSinceIn = exports.gitUnpulledChanges = exports.gitUncommittedChanges = exports.gitCurBranch = exports.gitLastTag = void 0;

var _shell = require("./shell");

const gitLastTag = async () => {
  try {
    let {
      stdout: commit
    } = await (0, _shell.exec)('git rev-list --tags --max-count=1', {
      logLevel: 'trace',
      errorLogLevel: 'info'
    });
    commit = commit.trim();
    if (commit === '') return null;
    let {
      stdout: tag
    } = await (0, _shell.exec)(`git describe --tags ${commit}`, {
      logLevel: 'trace'
    });
    tag = tag.trim();
    tag = tag !== '' ? tag : null;
    return tag;
  } catch (err) {
    return null;
  }
};

exports.gitLastTag = gitLastTag;

const gitCurBranch = async () => {
  const {
    stdout
  } = await (0, _shell.exec)('git symbolic-ref --short HEAD', {
    logLevel: 'trace'
  });
  return stdout.trim();
};

exports.gitCurBranch = gitCurBranch;

const gitUncommittedChanges = async () => {
  const {
    stdout
  } = await (0, _shell.exec)('git status --porcelain', {
    logLevel: 'trace'
  });
  return stdout.trim();
}; // Ripped off from: https://github.com/sindresorhus/np/blob/master/lib/git.js


exports.gitUncommittedChanges = gitUncommittedChanges;

const gitUnpulledChanges = async () => {
  const {
    stdout
  } = await (0, _shell.exec)('git rev-list --count --left-only @{u}...HEAD', {
    logLevel: 'trace'
  });
  return stdout.trim();
};

exports.gitUnpulledChanges = gitUnpulledChanges;

const gitDiffSinceIn = async (sinceTag, inPath) => {
  if (sinceTag == null) return 'CHANGED';
  const {
    stdout
  } = await (0, _shell.exec)(`git diff --name-only ${sinceTag} -- ${inPath}`, {
    logLevel: 'trace'
  });
  return stdout.trim();
};

exports.gitDiffSinceIn = gitDiffSinceIn;

const gitCommitChanges = async msg => {
  await (0, _shell.exec)('git add .', {
    logLevel: 'trace'
  });
  await (0, _shell.exec)(`git commit -m ${msg}`, {
    logLevel: 'trace'
  });
};

exports.gitCommitChanges = gitCommitChanges;

const gitAddTag = async tag => {
  await (0, _shell.exec)(`git tag ${tag}`, {
    logLevel: 'trace'
  });
};

exports.gitAddTag = gitAddTag;

const gitPushWithTags = async () => {
  await (0, _shell.exec)('git push --quiet', {
    logLevel: 'trace'
  });
  await (0, _shell.exec)('git push --tags --quiet', {
    logLevel: 'trace'
  });
};

exports.gitPushWithTags = gitPushWithTags;